@@ -11,12 +11,12 @@ from pathlib import Path
 import lxml.html  # type: ignore
 import click
 from scrapelib import Scraper, SQLiteCache
-from .utils import _display, _obj_to_dict, page_to_items, attr_has, attr_fields
+from .utils import _display, _obj_to_dict, attr_has, attr_fields
 from .sources import URL, Source
 from .pages import Page
 
 
-VERSION = "0.7.1"
+VERSION = "0.8.2"
 
 
 def scraper_params(func: typing.Callable) -> typing.Callable:
@@ -121,12 +121,14 @@ def get_page_class(dotted_name: str) -> type:
     return Cls
 
 
-def get_page(dotted_name: str) -> Page:
+def get_page(dotted_name: str, source: typing.Optional[str]) -> Page:
     Cls = get_page_class(dotted_name)
     if isinstance(Cls, Page):
+        if source:
+            Cls.source = URL(source)
         return Cls
     else:
-        return Cls()
+        return Cls(source=source)
 
 
 def get_new_filename(obj: typing.Any) -> str:
@@ -185,11 +187,16 @@ def _get_fake_input(Cls: type, data: typing.List[str], interactive: bool) -> typ
         k, v = item.split("=", 1)
         fake_input[k] = v
 
-    input_type = getattr(Cls, "input_type", None)
-
     if hasattr(Cls, "example_input"):
-        return getattr(Cls, "example_input")
+        example = getattr(Cls, "example_input")
+        for k, v in fake_input.items():
+            if isinstance(example, dict):
+                example[k] = v
+            else:
+                setattr(example, k, v)
+        return example
 
+    input_type = getattr(Cls, "input_type", None)
     if input_type:
         click.secho(f"{Cls.__name__} expects input ({input_type.__name__}): ")
         if dataclasses.is_dataclass(input_type):
@@ -234,7 +241,7 @@ def test(
     class_name: str,
     interactive: bool,
     data: typing.List[str],
-    source: str,
+    source: typing.Optional[str],
     pagination: bool,
     scraper: Scraper,
 ) -> None:
@@ -310,12 +317,18 @@ def test(
 @click.option(
     "-o", "--output-dir", default=None, help="override default output directory."
 )
+@click.option("-s", "--source", help="Provide (or override) source URL")
 @scraper_params
-def scrape(initial_page_name: str, output_dir: str, scraper: Scraper) -> None:
+def scrape(
+    initial_page_name: str,
+    output_dir: str,
+    source: typing.Optional[str],
+    scraper: Scraper,
+) -> None:
     """
     Run full scrape, and output data to disk.
     """
-    initial_page = get_page(initial_page_name)
+    initial_page = get_page(initial_page_name, source)
     if not output_dir:
         dirn = 1
         today = datetime.date.today().strftime("%Y-%m-%d")
@@ -335,7 +348,7 @@ def scrape(initial_page_name: str, output_dir: str, scraper: Scraper) -> None:
                 click.secho(f"{output_dir} exists and is not empty", fg="red")
                 sys.exit(1)
     count = 0
-    for item in page_to_items(scraper, initial_page):
+    for item in initial_page._to_items(scraper):
         save_object(item, output_path)
         count += 1
     click.secho(f"success: wrote {count} objects to {output_path}", fg="green")
@@ -343,6 +356,7 @@ def scrape(initial_page_name: str, output_dir: str, scraper: Scraper) -> None:
 
 @cli.command()
 @click.argument("initial_page_name")
+@click.option("-s", "--source", help="Provide (or override) source URL")
 @click.option(
     "-o",
     "--output-file",
@@ -350,7 +364,12 @@ def scrape(initial_page_name: str, output_dir: str, scraper: Scraper) -> None:
     help="override default output file [default: scout.json].",
 )
 @scraper_params
-def scout(initial_page_name: str, output_file: str, scraper: Scraper) -> None:
+def scout(
+    initial_page_name: str,
+    output_file: str,
+    source: typing.Optional[str],
+    scraper: Scraper,
+) -> None:
     """
     Run first step of scrape & output data to a JSON file.
 
@@ -363,8 +382,8 @@ def scout(initial_page_name: str, output_file: str, scraper: Scraper) -> None:
     (typically a ListPage derivative) surfacing enough information (perhaps a
     last_updated date) to know whether any of the other pages have been scraped.
     """
-    initial_page = get_page(initial_page_name)
-    items = list(page_to_items(scraper, initial_page, scout=True))
+    initial_page = get_page(initial_page_name, source)
+    items = list(initial_page._to_items(scraper, scout=True))
     with open(output_file, "w") as f:
         json.dump(items, f, indent=2)
     click.secho(f"success: wrote {len(items)} records to {output_file}", fg="green")
