@@ -8,6 +8,21 @@ import scrapelib
 import lxml.html  # type: ignore
 from openpyxl import load_workbook  # type: ignore
 from .sources import Source, URL
+from .utils import _obj_to_dict
+
+
+def _to_scout_result(result: typing.Any) -> typing.Dict[str, typing.Any]:
+    _next: typing.Optional[str]
+    if isinstance(result, Page):
+        data = _obj_to_dict(result.input)
+        _next = f"{result.__class__.__name__} source={result.source}"
+    else:
+        data = _obj_to_dict(result)
+        _next = None
+    return {
+        "data": data,
+        "__next__": _next,
+    }
 
 
 class MissingSourceError(Exception):
@@ -24,6 +39,9 @@ class Page:
     """
     Base class for all *Page* scrapers, used for scraping information from a single type of page.
 
+    For details on how these methods are called, it may be helpful to read
+    [Anatomy of a Scrape](anatomy-of-a-scrape.md).
+
     **Attributes**
 
     `source`
@@ -52,13 +70,27 @@ class Page:
     :   Source to fetch when invokking `spatula test`.
 
     `dependencies`
-    :   TODO: document
+    :   Dictionary mapping of names to `Page` objects that will be available before `process_page`.
+
+        For example:
+        ``` python
+
+        class EmployeeDetail(HtmlPage):
+            dependencies = {"awards": AwardsPage()}
+        ```
+
+        Means that before `EmployeeDetail.process_page` is called, it is guaranteed to have the
+        output from `AwardsPage` available as `self.awards`.
+
+        See [Specifying Dependencies](advanced-techniques.md#specifying-dependencies) for
+        a more detailed explanation.
 
     **Methods**
     """
 
     source: typing.Union[None, str, Source] = None
     dependencies: typing.Dict[str, "Page"] = {}
+    _cached_dependencies: typing.Dict[str, typing.Any] = {}
 
     def _fetch_data(self, scraper: scrapelib.Scraper) -> None:
         """
@@ -66,11 +98,21 @@ class Page:
         exactly once before process_page is invoked
         """
         # process dependencies first
-        for val, dep in self.dependencies.items():
+        for key, dep in self.dependencies.items():
+            use_cache = False
             if isinstance(dep, type):
                 dep = dep(self.input)
-            dep._fetch_data(scraper)
-            setattr(self, val, dep.process_page())
+            else:
+                use_cache = True
+
+            if key in self._cached_dependencies:
+                setattr(self, key, self._cached_dependencies[key])
+            else:
+                dep._fetch_data(scraper)
+                page_result = dep.process_page()
+                setattr(self, key, page_result)
+                if use_cache:
+                    self._cached_dependencies[key] = page_result
 
         if not self.source:
             try:
@@ -93,6 +135,49 @@ class Page:
         else:
             self.postprocess_response()
 
+    def _paginate(
+        self, scraper: scrapelib.Scraper, scout: bool
+    ) -> typing.Iterable[typing.Any]:
+        next_source = self.get_next_source()
+        if next_source:
+            # instantiate the same class with same input, but increment the source
+            next_page = type(self)(self.input, source=next_source)
+            yield from next_page._to_items(scraper, scout=scout)
+
+    def _to_items(
+        self, scraper: scrapelib.Scraper, *, scout: bool = False
+    ) -> typing.Iterable[typing.Any]:
+        # fetch data for a page, and then call the process_page entrypoint
+        try:
+            self._fetch_data(scraper)
+        except HandledError:
+            # ok to proceed, but nothing left to do with this page
+            yield from self._paginate(scraper, scout)
+            return
+        result = self.process_page()
+
+        # if we got back a generator, we need to process each result
+        if isinstance(result, typing.Generator):
+            # each item yielded might be a Page or an end-result
+            for item in result:
+                if scout:
+                    yield _to_scout_result(item)
+                elif isinstance(item, Page):
+                    yield from item._to_items(scraper)
+                else:
+                    yield item
+        elif scout:
+            yield _to_scout_result(result)
+        elif isinstance(result, Page):
+            # single Page result, recurse deeper
+            yield from result._to_items(scraper)
+        else:
+            # end-result, just return as-is
+            yield result
+
+        # check for next page
+        yield from self._paginate(scraper, scout)
+
     def __init__(
         self,
         input_val: typing.Any = None,
@@ -116,6 +201,19 @@ class Page:
         s += ")"
         return s
 
+    def do_scrape(
+        self, scraper: typing.Optional[scrapelib.Scraper] = None
+    ) -> typing.Iterable[typing.Any]:
+        """
+        yield results from this page and any subpages
+
+        :param scraper: Optional `scrapelib.Scraper` instance to use for running scrape.
+        :returns: Generator yielding results from the scrape.
+        """
+        if scraper is None:
+            scraper = scrapelib.Scraper()
+        yield from self._to_items(scraper)
+
     def get_source_from_input(self) -> typing.Union[None, str, Source]:
         """
         To be overridden.
